-- ============================================================
--   Database name:  TBC (HIS 20)                                   
--   DBMS name:      INFORMIX SQL 7.1                          
--   Created on:     9/26/00  10:24 AM                         
-- ============================================================

-- ============================================================
--   Table: PRODUCTDIM                                         
-- ============================================================
create table PRODUCTDIM
(
    FAMILY            VARCHAR(15)                       ,
    FAMILYNAME        VARCHAR(25)                       ,
    FAMILYATTR        VARCHAR(1)                        ,
    SKU               VARCHAR(15)                       ,
    SKUNAME           VARCHAR(25)                       
);

-- ============================================================
--   Table: FAMILY                                             
-- ============================================================
create table FAMILY
(
    FAMILYID          INTEGER                not null,
    FAMILY            VARCHAR(15)                       ,
    FAMILYNAME        VARCHAR(25)                       ,
    INTRODATE         DATETIME YEAR TO DAY    ,
    primary key (FAMILYID) constraint PK_FAMILY
);

-- ============================================================
--   Table: POPULATION                                         
-- ============================================================
create table POPULATION
(
    POPULATIONID      INTEGER                not null,
    POPGROUP          VARCHAR(15)                       ,
    POPULATION        INTEGER                        ,
    POPULATIONNAME    VARCHAR(25)                       ,
    primary key (POPULATIONID) constraint PK_POPULATION
);

-- ============================================================
--   Table: REGION                                             
-- ============================================================
create table REGION
(
    REGIONID          INTEGER                not null,
    REGION            VARCHAR(15)                       ,
    DIRECTOR          VARCHAR(50)                       ,
    primary key (REGIONID) constraint PK_REGION
);

-- ============================================================
--   Table: SCENARIO                                           
-- ============================================================
create table SCENARIO
(
    SCENARIOID        INTEGER                not null,
    SCENARIO          VARCHAR(15)                       ,
    ATTRIBUTE         VARCHAR(1)                        ,
    primary key (SCENARIOID) constraint PK_SCENARIO
);

-- ============================================================
--   Table: SUPPLIER                                           
-- ============================================================
create table SUPPLIER
(
    SUPPLIERID        INTEGER                not null,
    SUPPLIERNAME      VARCHAR(50)                       ,
    ADDRESS           VARCHAR(25)                       ,
    CITY              VARCHAR(25)                       ,
    STATE             VARCHAR(25)                       ,
    ZIP               VARCHAR(20)                       ,
    COUNTRY           VARCHAR(25)                       ,
    primary key (SUPPLIERID) constraint PK_SUPPLIER
);

-- ============================================================
--   Table: PRODUCT                                            
-- ============================================================
create table PRODUCT
(
    PRODUCTID         INTEGER                not null,
    FAMILYID          INTEGER                        ,
    SKU               VARCHAR(15)                       ,
    SKUNAME           VARCHAR(25)                       ,
    CAFFEINATED       VARCHAR(5)                        ,
    OUNCES            INTEGER                        ,
    PKGTYPE           VARCHAR(15)                       ,
    INTRODATE       DATETIME YEAR TO DAY                             ,
    primary key (PRODUCTID) constraint PK_PRODUCT
);

-- ============================================================
--   Table: MARKET                                             
-- ============================================================
create table MARKET
(
    STATEID           INTEGER                not null,
    REGIONID          INTEGER                        ,
    STATE             VARCHAR(25)                       ,
    POPULATIONID      INTEGER                        ,
    primary key (STATEID) constraint PK_MARKET
);

-- ============================================================
--   Table: SALESFACT                                          
-- ============================================================
create table SALESFACT
(
    STATEID           INTEGER                        ,
    PRODUCTID         INTEGER                        ,
    SCENARIOID        INTEGER                        ,
    SUPPLIERID        INTEGER                        ,
    TRANSDATE         DATETIME YEAR TO DAY         ,
    SALES             DOUBLE PRECISION               ,
    COGS              DOUBLE PRECISION               ,
    MARKETING         DOUBLE PRECISION               ,
    PAYROLL           DOUBLE PRECISION               ,
    MISC              DOUBLE PRECISION               ,
    OPENINGINVENTORY  DOUBLE PRECISION               ,
    ADDITIONS         DOUBLE PRECISION               
);

alter table PRODUCT
    add constraint (foreign key  (FAMILYID)
       references FAMILY (FAMILYID) constraint FK_REF_72_72);

alter table MARKET
    add constraint (foreign key  (REGIONID)
       references REGION (REGIONID) constraint FK_REF_75_75);

alter table MARKET
    add constraint (foreign key  (POPULATIONID)
       references POPULATION (POPULATIONID) constraint FK_REF_78_78);

alter table SALESFACT
    add constraint (foreign key  (SUPPLIERID)
       references SUPPLIER (SUPPLIERID) constraint FK_REF_60_60);

alter table SALESFACT
    add constraint (foreign key  (STATEID)
       references MARKET (STATEID) constraint FK_REF_63_63);

alter table SALESFACT
    add constraint (foreign key  (SCENARIOID)
       references SCENARIO (SCENARIOID) constraint FK_REF_66_66);

alter table SALESFACT
    add constraint (foreign key  (PRODUCTID)
       references PRODUCT (PRODUCTID) constraint FK_REF_69_69);



